<?php

/**
 * Business rules for Pages
 */
class Page extends AppModel {

	public $displayField = 'title';

	public $actsAs = array(
		'Routable.Routable' => array(
			'config' => 'EvCore'
		),
		'MetaData.Meta',
		'EvNavigation.Navigatable',
		'EvTemplates.Template' => array(
			'formInject' => true
		)
	);

	public $validate = array(
		'title' => array(
			'required' => array(
				'rule' => 'notBlank',
				'message' => 'cannot be blank'
			)
		),
		'internal_title' => [
			'unique' => [
				'rule' => 'isUnique',
				'message' => 'The internal title must be unique.',
				'allowEmpty' => true
			]
		],

	);

	/**
	 * Model pre-save logic
	 * @param array $options
	 * @return bool
	 */
	public function beforeSave($options = array()) {
		// remove trailing empty paragraph tag from body
		if (isset($this->data[$this->alias]['body']) && !empty($this->data[$this->alias]['body'])) {

			$this->data[$this->alias]['body'] = preg_replace("/(<p[^>]*>[\s|&nbsp;]*<\/p>\n?)*$/", '', $this->data[$this->alias]['body']);
		}
		// If this page has a redirect setup for it then we want to remove the
		// Routable behaviour and not save a route. This page content cannot be
		// directly accessed.
		if (!empty($this->data[$this->alias]['redirect_url'])) {
			unset($this->data['Route']);
			$this->Behaviors->unload('Routable.Routable');
		}
		return parent::beforeSave($options);
	}

}
